pub struct Completion<K, S, Context = ()> {
pub context: Context,
pub delivery: Delivery<K, S>,
pub valid: bool,
}Expand description
Completed consumer validation for a delivery.
Fields
context: ContextResolver-specific context associated with the delivery attempt.
delivery: Delivery<K, S>Key and subscribers that were passed to the consumer.
valid: boolWhether the consumer accepted the response as valid for the key.