pub struct Engine<E, P, D, B, Key, Con, Pro, NetS, NetR>where
E: BufferPooler + Clock + Spawner + Rng + Metrics,
P: PublicKey,
D: Provider<PublicKey = P>,
B: Blocker<PublicKey = P>,
Key: Span,
Con: Consumer<Key = Key, Value = Bytes>,
Pro: Producer<Key = Key>,
NetS: Sender<PublicKey = P>,
NetR: Receiver<PublicKey = P>,
Con::Subscriber: Eq,{ /* private fields */ }Expand description
Manages incoming and outgoing P2P requests, coordinating fetch and serve operations.
Implementations
Sourceimpl<E, P, D, B, Key, Con, Pro, NetS, NetR> Engine<E, P, D, B, Key, Con, Pro, NetS, NetR>where
E: BufferPooler + Clock + Spawner + Rng + Metrics,
P: PublicKey,
D: Provider<PublicKey = P>,
B: Blocker<PublicKey = P>,
Key: Span,
Con: Consumer<Key = Key, Value = Bytes>,
Pro: Producer<Key = Key>,
NetS: Sender<PublicKey = P>,
NetR: Receiver<PublicKey = P>,
Con::Subscriber: Clone + Ord + Send + 'static,
impl<E, P, D, B, Key, Con, Pro, NetS, NetR> Engine<E, P, D, B, Key, Con, Pro, NetS, NetR>where
E: BufferPooler + Clock + Spawner + Rng + Metrics,
P: PublicKey,
D: Provider<PublicKey = P>,
B: Blocker<PublicKey = P>,
Key: Span,
Con: Consumer<Key = Key, Value = Bytes>,
Pro: Producer<Key = Key>,
NetS: Sender<PublicKey = P>,
NetR: Receiver<PublicKey = P>,
Con::Subscriber: Clone + Ord + Send + 'static,
Sourcepub fn new(
context: E,
cfg: Config<P, D, B, Key, Con, Pro>,
) -> (Self, Mailbox<Key, P, Con::Subscriber>)
pub fn new( context: E, cfg: Config<P, D, B, Key, Con, Pro>, ) -> (Self, Mailbox<Key, P, Con::Subscriber>)
Creates a new Actor with the given configuration.
Returns the actor and a mailbox to send messages to it.
Sourcepub fn start(self, network: (NetS, NetR)) -> Handle<()>
pub fn start(self, network: (NetS, NetR)) -> Handle<()>
Runs the actor until the context is stopped.
The actor will handle:
- Fetching data from other peers and notifying the
Consumer - Serving data to other peers by requesting it from the
Producer