pub enum Outcome {
Invalid,
Complete,
Ambiguous,
Ignored,
}Expand description
Consumer disposition for a delivered response.
Variants
Invalid
The response is invalid for the peer-visible key.
Network resolvers may penalize the serving peer before retrying.
Complete
The response is valid and satisfies every delivered subscriber.
Ambiguous
The peer-visible key admits multiple valid responses, and this response does not satisfy every delivered subscriber.
The resolver retries the key without penalizing the serving peer so another response can be tried.
Ignored
The consumer no longer needs the key, so the response does not need to be validated.
The resolver retires the key and all of its subscribers without retrying or attributing the response to its source.